# KaclsKeyMetadata

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**kacls_data** | **str** | Opaque data generated and used by the key access control list service. Maximum size: 8 KiB. | [optional] 
**kacls_uri** | **str** | The URI of the key access control list service that manages the private key. | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

